==> bootstrap-lombardia-2.0.1.tgz: package/README.md <==
# Bootstrap Lombardia

[![Versione](https://img.shields.io/npm/v/bootstrap-lombardia.svg?logo=npm)](https://github.com/RegioneLombardia/bootstrap-lombardia/releases)
[![Build](https://github.com/RegioneLombardia/bootstrap-lombardia/actions/workflows/publish-release.yml/badge.svg)](https://github.com/RegioneLombardia/bootstrap-lombardia/actions)
[![GitHub issues](https://img.shields.io/github/issues/RegioneLombardia/bootstrap-lombardia.svg)](https://github.com/RegioneLombardia/bootstrap-lombardia/issues)
[![License](https://img.shields.io/github/license/RegioneLombardia/bootstrap-lombardia.svg)](https://github.com/RegioneLombardia/bootstrap-lombardia/blob/main/LICENSE)


_⚠️ [La versione di Bootstrap Lombardia (basata su Bootstrap 4) è stata ufficialmente deprecata](https://github.com/italia/bootstrap-lombardia/tree/1.x)_

Bootstrap Regione Lombardia è un *fork* di Bootstrap Italia, modificato per aderire all **Sistema di Identità Visiva Digitale di Regione Lombardia**.

Bootstrap Italia, a sua volta, è un tema basato su [Bootstrap 5](https://getbootstrap.com/docs/5.1/getting-started/introduction/) e conforme alle [Linee Guida di design per i siti internet e i servizi digitali delle Pubbliche Amministrazioni](https://docs.italia.it/italia/design/lg-design-servizi-web/).

Bootstrap Lombardia eredita tutte le funzionalità, componenti, mixins, grid system, e altro già presenti in Bootstrap 5 ed in Bootstrap Italia, e le personalizza secondo le "Linee Guida per il design e l’identità visiva digitale di Regione Lombardia". Puoi scoprire di più tramite la [Documento in formato "cartaceo"](https://regionelombardia.github.io/bootstrap-lombardia/docs/it25/download/Linee-guida_design_identita-visiva_Regione-Lombardia.pdf) che illustra gli elementi principali e fondanti dell’identità visiva di Regione Lombardia necessari a garantirne la riconoscibilità su tutti i progetti in digitale.

**[Vedi la documentazione completa »](https://regionelombardia.github.io/bootstrap-lombardia/)**

oppure

**[Scarica l'ultima versione della libreria »](https://github.com/regionelombardia/bootstrap-lombardia/releases)**

## Indice

- [Segnalazione bug e richieste](#segnalazione-bug-e-richieste-di-aiuto)
- [Licenze software dei componenti di terze parti](#licenze-software-dei-componenti-di-terze-parti)

## Segnalazione bug e richieste di aiuto

Vuoi segnalare un bug o fare una richiesta?

Prima di tutto assicurati che sia un problema relativo al tema Bootstrap Lombardia e non alle librerie da cui deriva
(in tal caso puoi fare riferimento al [repository di Bootstrap Italia](https://italia.github.io/bootstrap-italia) o al [repository di Bootstrap](https://github.com/twbs/bootstrap)).  
Puoi [creare una issue](https://github.com/RegioneLombardia/bootstrap-lombardia/issues) su GitHub, nella sezione apposita.


## Licenze software dei componenti di terze parti

### Componenti distribuiti con Bootstrap Regione Lombardia

Vengono di seguito elencati i componenti distribuiti con Bootstrap Lombardia che hanno una propria licenza diversa da CC0.

- [Bootstrap 5](https://getbootstrap.com) © Twitter, Inc., licenza MIT
- [Popper.js](https://popper.js.org) © Floating UI contributors, licenza MIT
- [SplideJS](https://splidejs.com) © Naotoshi Fujita, licenza MIT
- [Accessible Autocomplete](https://alphagov.github.io/accessible-autocomplete) © Crown Copyright (Government Digital Service), licenza MIT
- [AnimeJS](https://animejs.com) © Julian Garnier, licenza MIT
- [Just Validate](https://just-validate.dev) © Horprogs, licenza MIT
- [Masonry Layout](https://masonry.desandro.com) © David DeSandro, licenza MIT
- [Progressbar.js](https://kimmobrunfeldt.github.io/progressbar.js) © Kimmo Brunfeldt, licenza MIT

### Principali dipendenze per la fase di compilazione e sviluppo

- Generatore di siti statici per ruby [Jekyll](https://jekyllrb.com), © Tom Preston-Werner and Jekyll contributors, licenza MIT
- Tool per il testing della correttezza formale dell'HTML [html-proofer](https://github.com/gjtorikian/html-proofer), © Garen Torikian, licenza MIT
- Tool per il reload automatico del browser [Browser Sync](https://www.browsersync.io/) Apache License Version 2.0
- Gestione del versionamento [conventional-changelog](https://github.com/conventional-changelog/conventional-changelog/) © conventional-changelog team, ISC License
- Build system per le librerie Javascript e CSS [Rollup.js](https://rollupjs.org/), © [questi contributori](https://github.com/rollup/rollup/graphs/contributors), licenza MIT
- Code formatter per Javascript [Prettier](https://prettier.io/), © James Long and contributors, licenza MIT
- Compilazione SASS [sass](https://github.com/sass/dart-sass), © Google Inc., licenza MIT
- GitHub REST API client per JavaScript [Octokit rest.js](https://octokit.github.io/rest.js/) © Cloud9 IDE, Inc. (Mike de Boer), 2017-2018 Octokit contributors, licenza MIT

### Componenti utilizzati per la documentazione

Di seguito sono elencati invece i componenti utilizzati per il sito della documentazione ma non ridistribuiti nella libreria Bootstrap Italia

- [tsParticles](https://particles.js.org/) © Matteo Bruni, licenza MIT
- [clipboard.js](https://clipboardjs.com/) © Zeno Rocha, licenza MIT
- [AnchorJS](https://www.bryanbraun.com/anchorjs/) © Bryan Braun, licenza MIT
- [Algolia DocSearch](https://docsearch.algolia.com/) © Algolia, licenza MIT

## Licenza

La licenza di Bootstrap Lombardia è **BSD 3-Clause** ed è visibile nel file [LICENSE](https://github.com/RegioneLombardia/bootstrap-lombardia/blob/main/LICENSE).

==> bootstrap-lombardia-2.4.1.tgz: package/README.md <==
# Bootstrap Lombardia

[![Versione](https://img.shields.io/npm/v/bootstrap-lombardia.svg?logo=npm)](https://github.com/RegioneLombardia/bootstrap-lombardia/releases)
[![Build](https://github.com/RegioneLombardia/bootstrap-lombardia/actions/workflows/publish-release.yml/badge.svg)](https://github.com/RegioneLombardia/bootstrap-lombardia/actions)
[![GitHub issues](https://img.shields.io/github/issues/RegioneLombardia/bootstrap-lombardia.svg)](https://github.com/RegioneLombardia/bootstrap-lombardia/issues)
[![License](https://img.shields.io/github/license/RegioneLombardia/bootstrap-lombardia.svg)](https://github.com/RegioneLombardia/bootstrap-lombardia/blob/main/LICENSE)


_⚠️ [La versione di Bootstrap Lombardia (basata su Bootstrap 4) è stata ufficialmente deprecata](https://github.com/italia/bootstrap-lombardia/tree/1.x)_

Bootstrap Regione Lombardia è un *fork* di Bootstrap Italia, modificato per aderire all **Sistema di Identità Visiva Digitale di Regione Lombardia**.

Bootstrap Italia, a sua volta, è un tema basato su [Bootstrap 5](https://getbootstrap.com/docs/5.1/getting-started/introduction/) e conforme alle [Linee Guida di design per i siti internet e i servizi digitali delle Pubbliche Amministrazioni](https://docs.italia.it/italia/design/lg-design-servizi-web/).

Bootstrap Lombardia eredita tutte le funzionalità, componenti, mixins, grid system, e altro già presenti in Bootstrap 5 ed in Bootstrap Italia, e le personalizza secondo le "Linee Guida per il design e l’identità visiva digitale di Regione Lombardia". Puoi scoprire di più tramite la [Documento in formato "cartaceo"](https://regionelombardia.github.io/bootstrap-lombardia/docs/it25/download/Linee-guida_design_identita-visiva_Regione-Lombardia.pdf) che illustra gli elementi principali e fondanti dell’identità visiva di Regione Lombardia necessari a garantirne la riconoscibilità su tutti i progetti in digitale.

**[Vedi la documentazione completa »](https://regionelombardia.github.io/bootstrap-lombardia/)**

oppure

**[Scarica l'ultima versione della libreria »](https://github.com/regionelombardia/bootstrap-lombardia/releases)**

## Indice

- [Segnalazione bug e richieste](#segnalazione-bug-e-richieste-di-aiuto)
- [Licenze software dei componenti di terze parti](#licenze-software-dei-componenti-di-terze-parti)

## Segnalazioni e richieste di aiuto

Vuoi fare una segnalazione o una richiesta?

Prima di tutto assicurati che sia un problema relativo al tema Bootstrap Lombardia e non alle librerie da cui deriva
(in tal caso puoi fare riferimento al [repository di Bootstrap Italia](https://italia.github.io/bootstrap-italia) o al [repository di Bootstrap](https://github.com/twbs/bootstrap)).  
Puoi [creare una issue](https://github.com/RegioneLombardia/bootstrap-lombardia/issues) su GitHub, nella sezione apposita.

## Licenze software dei componenti di terze parti

### Componenti distribuiti con Bootstrap Regione Lombardia

Vengono di seguito elencati i componenti distribuiti con Bootstrap Lombardia che hanno una propria licenza diversa da CC0.

- [Bootstrap 5](https://getbootstrap.com) © Twitter, Inc., licenza MIT
- [Popper.js](https://popper.js.org) © Floating UI contributors, licenza MIT
- [SplideJS](https://splidejs.com) © Naotoshi Fujita, licenza MIT
- [Accessible Autocomplete](https://alphagov.github.io/accessible-autocomplete) © Crown Copyright (Government Digital Service), licenza MIT
- [AnimeJS](https://animejs.com) © Julian Garnier, licenza MIT
- [Just Validate](https://just-validate.dev) © Horprogs, licenza MIT
- [Masonry Layout](https://masonry.desandro.com) © David DeSandro, licenza MIT
- [Progressbar.js](https://kimmobrunfeldt.github.io/progressbar.js) © Kimmo Brunfeldt, licenza MIT

### Principali dipendenze per la fase di compilazione e sviluppo

- Generatore di siti statici per ruby [Jekyll](https://jekyllrb.com), © Tom Preston-Werner and Jekyll contributors, licenza MIT
- Tool per il testing della correttezza formale dell'HTML [html-proofer](https://github.com/gjtorikian/html-proofer), © Garen Torikian, licenza MIT
- Tool per il reload automatico del browser [Browser Sync](https://www.browsersync.io/) Apache License Version 2.0
- Gestione del versionamento [conventional-changelog](https://github.com/conventional-changelog/conventional-changelog/) © conventional-changelog team, ISC License
- Build system per le librerie Javascript e CSS [Rollup.js](https://rollupjs.org/), © [questi contributori](https://github.com/rollup/rollup/graphs/contributors), licenza MIT
- Code formatter per Javascript [Prettier](https://prettier.io/), © James Long and contributors, licenza MIT
- Compilazione SASS [sass](https://github.com/sass/dart-sass), © Google Inc., licenza MIT
- GitHub REST API client per JavaScript [Octokit rest.js](https://octokit.github.io/rest.js/) © Cloud9 IDE, Inc. (Mike de Boer), 2017-2018 Octokit contributors, licenza MIT

### Componenti utilizzati per la documentazione

Di seguito sono elencati invece i componenti utilizzati per il sito della documentazione ma non ridistribuiti nella libreria Bootstrap Italia

- [tsParticles](https://particles.js.org/) © Matteo Bruni, licenza MIT
- [clipboard.js](https://clipboardjs.com/) © Zeno Rocha, licenza MIT
- [AnchorJS](https://www.bryanbraun.com/anchorjs/) © Bryan Braun, licenza MIT
- [Algolia DocSearch](https://docsearch.algolia.com/) © Algolia, licenza MIT

## Licenza

La licenza di Bootstrap Lombardia è **BSD 3-Clause** ed è visibile nel file [LICENSE](https://github.com/RegioneLombardia/bootstrap-lombardia/blob/main/LICENSE).
